@@ -1,16 +1,16 @@
 ;;; -*- Emacs-Lisp -*-
 ;;; <plaintext>
 ;;; revive.el: Resume Emacs.
-;;; (c) 1994-1999 by HIROSE Yuuji [yuuji@ae.keio.ac.jp]
-;;; $Id: revive.el,v 2.13 1998/04/01 03:52:08 yuuji Exp yuuji $
-;;; Last modified Sat Jan 16 12:42:41 1999 on firestorm
+;;; (c) 1994-2003 by HIROSE Yuuji [yuuji@gentei.org]
+;;; $Id: revive.el,v 2.18 2003/06/22 05:11:46 yuuji Exp $
+;;; Last modified Sun Jun 22 14:11:22 2003 on firestorm
 
 ;;;[[[   NOTICE  NOTICE  NOTICE  NOTICE  NOTICE    ]]]
 ;;;--------------------------------------------------------------------------
 ;;;	If you are using `windows.el', you can omit the settings of
 ;;;	define-key and autoload.
-;;;	windows.el𕁒igĂꍇ revive.el ̂߂̃L[̊蓖
-;;;	Ăautoload̐ݒKv܂B
+;;;	windows.elʻȤäƤ revive.el ΤΥγ
+;;;	Ƥautoload⤹ɬפޤ
 ;;;--------------------------------------------------------------------------
 ;;;
 ;;;		Resume Emacs:		revive.el
@@ -92,7 +92,7 @@
 ;;;		(revive:prop-major-mode x)	;major-mode
 ;;;		(revive:prop-point x)		;(point)
 ;;;		(revive:prop-mark x)		;(mark)
-;;;		(revive:prop-varlist x)		;list of pairs of (var . val)
+;;;		(revive:prop-varlist x)		;alist of pairs of (var . val)
 ;;;
 ;;;[For programmers]
 ;;;
@@ -131,112 +131,111 @@
 ;;;	  Comments  and bug   reports  are welcome. Don't  hesitated  to
 ;;;	report.  My possible e-mail address is following.
 ;;;
-;;;						yuuji@ae.keio.ac.jp
-;;;						pcs39334@asciinet.or.jp
+;;;							yuuji@gentei.org
 ;;;
 ;;; Japanese Document follows:
 ;;;
-;;;yreviveƂ́z
+;;;reviveȤϡ
 ;;;
-;;;	  revive.el gƁAEmacs gp̏Ԃt@CɃZ[uāA
-;;;	 Emacs N鎞ɂ̏ԂɕA邱Ƃł܂B
-;;;	EBhE̕Ԃ̂ saveconf  desktop 
-;;;	炢炵Ălɂ߂łB
+;;;	  revive.el ȤȡEmacs ѻξ֤ե˥֤ơ
+;;;	 Emacs ưˤξ֤뤳ȤǤޤ
+;;;	󥦥ɥʬ֤Τ saveconf  desktop 
+;;;	餤餷Ƥͤˤ⤪Ǥ
 ;;;
-;;;ygݍݕz
+;;;Ȥ߹
 ;;;
-;;;	  revive.el  load-path ̒ʂfBNgɓA~/.emacs 
-;;;	ȉ̋LqĂB
+;;;	  revive.el  load-path ̤äǥ쥯ȥ졢~/.emacs 
+;;;	ʲεҤƤ
 ;;;
 ;;;	  (autoload 'save-current-configuration "revive" "Save status" t)
 ;;;	  (autoload 'resume "revive" "Resume Emacs" t)
 ;;;	  (autoload 'wipe "revive" "Wipe emacs" t)
 ;;;
-;;;	ď̊֐DȃL[Ɋ蓖ĂĂBȉ͗łB
+;;;	ƾδؿ򹥤ʥ˳ƤƤʲǤ
 ;;;
 ;;;	  (define-key ctl-x-map "S" 'save-current-configuration)
 ;;;	  (define-key ctl-x-map "F" 'resume)
 ;;;	  (define-key ctl-x-map "K" 'wipe)
 ;;;
-;;;ygz
+;;;ڻȤ
 ;;;
-;;;	   define-key ꍇɂ́AC-x S Ō݂̕ҏWԂZ[u
-;;;	邱Ƃł܂Bsave-current-configuration ֐ɐ
-;;;	ƕ̏ԂʁXɃZ[uł܂BuC-u 2 C-x SvƂ2
-;;;	Ԃ̃obt@ɌZ[uł܂B[h鎞l
-;;;	uC-u 2 C-x Fvƃ^Cv2Ԃ̃obt@Ԃ[h܂B
+;;;	   define-key 򤷤ˤϡC-x S ǸߤԽ֤򥻡
+;;;	뤳ȤǤޤsave-current-configuration ؿ˿
+;;;	ʣξ̡֤˥֤ǤޤC-u 2 C-x SפȤ2
+;;;	֤ΥХåե˸򥻡֤ǤޤɤƱͤ
+;;;	C-u 2 C-x Fפȥפ2֤ΥХåե֤ɤޤ
 ;;;
-;;;yϐ̃Z[uz
+;;;ѿΥ֡
 ;;;
-;;;	  ϐ̒lZ[uĂƂł܂BftHgŃZ[u 
-;;;	global ϐ revive:save-variables-global-default ɁAlocal 
-;;;	 revive:save-variables-local-default ɒ`Ă܂B
-;;;	̕ϐۑꍇ́Arevive:save-variables-global-private 
-;;;	 global ϐArevive:save-variables-local-private  local 
-;;;	ϐꂼꃊXǧ`Œ`Ă܂BႦ gmhist g
-;;;	Ăꍇɂ́A
+;;;	  ѿͤ⥻֤ƤȤǤޤǥեȤǥ֤ 
+;;;	global ѿ revive:save-variables-global-default ˡlocal 
+;;;	 revive:save-variables-local-default Ƥޤ
+;;;	ѿ¸ϡrevive:save-variables-global-private 
+;;;	 global ѿ̾revive:save-variables-local-private  local 
+;;;	ѿ̾򤽤줾ꥹȤηƤޤ㤨 gmhist Ȥ
+;;;	Ƥˤϡ
 ;;;
 ;;;		(setq revive:save-variables-global-private
 ;;;		      '(file-history buffer-history minibuffer-history))
 ;;;
-;;;	Ȃǂ ~/.emacs ɏĂƉKł傤B
+;;;	ʤɤ ~/.emacs ˽񤤤ƤȲŬǤ礦
 ;;;
-;;;yʂłȂobt@̈z
+;;;̤ǤʤХåեΰ
 ;;;
-;;;	  mh-rmail ł̓Jgobt@ mh-folder-mode, gnus ł̓J
-;;;	gobt@ gnus-Group-mode ɂȂ܂B̑Ή֌ẂAϐ 
-;;;	revive:major-mode-command-alist-default ɏĂ܂B̕
-;;;	ɓo^ĂȊÔ̂`ꍇ́A
+;;;	  mh-rmail ǤϥȥХåե mh-folder-mode, gnus Ǥϥ
+;;;	ȥХåե gnus-Group-mode ˤʤޤбطϡѿ 
+;;;	revive:major-mode-command-alist-default ˽񤫤Ƥޤ
+;;;	ϿƤʳΤΤϡ
 ;;;
 ;;;		(setq revive:major-mode-command-alist-private
 ;;;		  '((hogehoge-mode	. hoge)
 ;;;		    (herohero-mode	. herohero)
-;;;		    ("^Cvj["	. trr)))
+;;;		    ("ס˥塼"	. trr)))
 ;;;
-;;;	̂悤 revive:major-mode-command-alist-private ̒lݒ肷
-;;;	Ǝ resume ɎIɑΉR}hN܂B
-;;;	̗ɂ悤ɁAmajor-mode(V{)̑ buffer-name
-;;;	()w肷邱Ƃł܂B
+;;;	Τ褦 revive:major-mode-command-alist-private ͤꤹ
+;;;	ȼ resume ˼ưŪб륳ޥɤưޤ
+;;;	ˤ褦ˡmajor-mode(ܥ) buffer-name
+;;;	(ʸ)ꤹ뤳ȤǤޤ
 ;;;
-;;;	  ܂ASKK̎̂悤ɃW[Ƃ܂ȂȂĂ
-;;;	܂obt@ꍇ́Aϐ revive:ignore-buffer-pattern ɂ
-;;;	̃obt@}b`悤ȐK\ݒ肵ĂB
+;;;	  ޤSKKμΤ褦˥ꥸ塼हȤޤưʤʤäƤ
+;;;	ޤХåեϡѿ revive:ignore-buffer-pattern ˤ
+;;;	ΥХåե̾ޥå褦ɽꤷƤ
 ;;;
-;;;yvOgz
+;;;ڥץफȤ
 ;;;
-;;;	  pŃhLg [For programmers] ̍QƂĂB
+;;;	  Ѹǥɥ [For programmers] ι򻲾ȤƤ
 ;;;
-;;;yƂz
+;;;ڤȤ
 ;;;
-;;;	  ŏ resume Ƃt@ĈłAEmacs 19 ̃fB
-;;;	Ng resume.el Ƃt@CăVbN󂯂܂B
-;;;	̓R}hCŉ emacs ƑłĂAɋNĂ 
-;;;	emacs Ƀt@CnƂ(s[[)vOŁuǂ 
-;;;	resume ˂vƌȂ܂䖝 revive.el Ƀl[
-;;;	܂B܂Asaveconf ł desktop łȂȂ
-;;;	EBhEԂ̕T|[gƌ̂ɁcAȂĂ
-;;;	͉płɂ͏Ȃ:-)B
+;;;	  ǽ resume Ȥե̾äΤǤEmacs 19 Υǥ
+;;;	쥯ȥ resume.el Ȥե뤬äƥåޤ
+;;;	ϥޥɥ饤ǲ emacs ǤäƤ⡢˵ưƤ 
+;;;	emacs ˥եϤȤ(ԡ)ץǡ֤ɤ 
+;;;	resume ͤפȸʤޤ revive.el ˥͡
+;;;	षޤޤäsaveconf Ǥ desktop Ǥʤʤ
+;;;	ɥʬ֤򥵥ݡȤȸΤˡġʤƤ
+;;;	ϱѸǤˤϽ񤱤ʤ:-)
 ;;;
-;;;y舵z
+;;;ڼ갷
 ;;;
-;;;	  ̃vÓAt[\tgEFAƂ܂B̃vO
-;;;	gpĐȂ錋ʂɑ΂Ă҂͈؂̐ӔC𕉂
-;;;	̂Ƃ܂ARgoO|[g͑傢Ɋ}
-;;;	BCyɂABA͈ȉ̃AhX܂ł肢
-;;;	(1999/1)B
-;;;						yuuji@ae.keio.ac.jp
-;;;						yuuji@gentei.org
+;;;	  Υץϡե꡼եȥȤޤΥץ
+;;;	Ѥʤ̤ФƤԤϰڤǤ
+;;;	ΤȤޤȤХݡȤ礤˴ޤ
+;;;	ڤˤϢϢϰʲΥɥ쥹ޤǤꤤ
+;;;	(2003/6)
+;;;							yuuji@gentei.org
 
 (defconst revive:version
-  "$Id: revive.el,v 2.13 1998/04/01 03:52:08 yuuji Exp yuuji $"
+  "$Id: revive.el,v 2.18 2003/06/22 05:11:46 yuuji Exp $"
   "Version of revive.el")
 
 (defconst revive:version-prefix ";;;")
 
 (defvar revive:emacs-19 (string< "18" (substring emacs-version 0 2)))
+(defvar revive:xemacs-p (featurep 'xemacs))
 (defun revive:window-edges (&optional window)
   "Borrowed from tapestry.el"
-  (if (fboundp 'window-pixel-edges)
+  (if (and (fboundp 'window-pixel-edges) revive:xemacs-p)
       (let ((edges (window-pixel-edges window))
             tmp)
         (setq tmp edges)
@@ -257,7 +256,7 @@
  ((fboundp 'frame-height)
   (fset 'revive:screen-height 'frame-height)
   (fset 'revive:screen-width 'frame-width))
- (t (error "I don't know how to run revive.el on this Emacs...")) )
+ (t (error "I don't know how to run revive.el on this Emacs...")))
 
 (defun revive:minx () 0)
 (defun revive:miny ()
@@ -280,8 +279,7 @@
     (setq curwin win wlist (list win))
     (while (not (eq curwin (setq win (next-window win))))
       (setq wlist (append wlist (list win)))) ;use append to preserve order
-    wlist)
-)
+    wlist))
 
 (defun revive:window-buffer-list ()
   "Return the all shown buffer list.
@@ -302,8 +300,7 @@ Each element consists of '(buffer-file-name window-start point)"
 			     (point))))
 	      wlist (cdr wlist)))
       (select-window curw)
-      wblist))
-)
+      wblist)))
 
 (defun revive:all-window-edges ()
   "Return the all windows edges by list."
@@ -311,8 +308,7 @@ Each element consists of '(buffer-file-name window-start point)"
     (while wlist
       (setq edges (append edges (list (revive:window-edges (car wlist))))
 	    wlist (cdr wlist)))
-    edges)
-)
+    edges))
 
 (defun revive:select-window-by-edge (x y)
   "Select window whose north west corner is (X, Y).
@@ -333,8 +329,7 @@ If the matching window is not found, select the nearest window."
 	   (setq min s2 minwin win)))
 	 (if (eq win curwin) (throw 'found nil)) ;select the nearest window
 	 (setq win (next-window win))))
-     (select-window minwin)))
-)
+     (select-window minwin))))
 
 (defun revive:split-window-safe (window size &optional hor-flag)
   "Same as split-window but avoids error."
@@ -343,8 +338,7 @@ If the matching window is not found, select the nearest window."
    (min (max (if hor-flag window-min-width window-min-height) size)
 	(if hor-flag (- (revive:screen-width) window-min-width 1)
 	  (- (revive:screen-height) window-min-height 1)))
-   hor-flag)
-)
+   hor-flag))
 
 (defun revive:restore-winconf (x1 y1 x2 y2 edges)
   "Restore partial window configuration.
@@ -416,10 +410,7 @@ EDGES is a list of sub-windows' edges."
 	  (revive:restore-winconf x1 y1 div-x y2 former)
 	  (revive:restore-winconf div-x y1 x2 y2 latter)
 	  (message "||"))
-	 (t (message "dame!"))))
-      )
-     ))
-)
+	 (t (message "dame!"))))))))
 
 (defvar revive:major-mode-command-alist-default
   '((gnus-Group-mode	. gnus)
@@ -431,6 +422,10 @@ EDGES is a list of sub-windows' edges."
     (dired-mode		. revive:dired)
     (view-mode		. revive:view)
     (Info-mode		. info)
+    (mpg123-mode	. revive:mpg123)
+    ;;(c-mode		. revive:c-set-style)
+    ;;(cc-mode		. revive:c-set-style)
+    ;;(java-mode		. revive:c-set-style)
     )
   "Default alist of major-mode vs. command name.")
 (defvar revive:major-mode-command-alist-private nil
@@ -456,21 +451,23 @@ EDGES is a list of sub-windows' edges."
 
 (defvar revive:save-variables-local-default
   '(buffer-read-only
-    truncate-lines fill-column fill-prefix case-fold-search default-directory
-    )
+    truncate-lines fill-column fill-prefix case-fold-search default-directory)
   "Default list of the local variables to save.")
 (defvar revive:save-variables-local-private nil
   "*User defined list of the local variables to save.")
 
 (defvar revive:save-variables-mode-local-default
   '((dired-mode dired-actual-switches)
-    (yatex-mode YaTeX-math-mode YaTeX-modify-mode YaTeX-parent-file))
+    (yatex-mode YaTeX-math-mode YaTeX-modify-mode YaTeX-parent-file)
+    (yahtml-mode YaTeX-parent-file)
+    (c-mode c-indentation-style c-basic-offset)
+    (cc-mode c-indentation-style c-basic-offset)
+    (java-mode c-indentation-style c-basic-offset))
   "Default list of the mode specific local variables to save.
 Actually, revive doesn't make the buffer local variables assuming
 those variable have already localized by their major mode.")
 (defvar revive:save-variables-mode-local-private
-  '((dired-mode dired-actual-switches)
-    (yatex-mode YaTeX-math-mode YaTeX-modify-mode))
+  nil
   "*User defined list of the mode specific local variables to save.")
 
 (defvar revive:configuration-file
@@ -496,16 +493,14 @@ window-edges."
 		      (/ (+ (* curh (nth 3 e)) (/ height 2)) height))
 	      normalized (append normalized (list n))
 	      edgelist (cdr edgelist)))
-      normalized))
-)
+      normalized)))
 
 (defun construct-window-configuration (edgelist)
   "Restore window configuration by EDGELIST.  EDGELIST should be sorted."
   (delete-other-windows)
   (revive:restore-winconf (revive:minx) (revive:miny)
 			  (revive:screen-width)
-			  (1- (revive:screen-height)) edgelist)
-)
+			  (1- (revive:screen-height)) edgelist))
 
 ;;;###autoload
 (defun current-window-configuration-printable ()
@@ -542,8 +537,7 @@ property list is formed as
 				     (window-start))))
 	      wlist (cdr wlist)))
       (select-window curwin)
-      (list (revive:screen-width) (revive:screen-height) edges buflist)))
-)
+      (list (revive:screen-width) (revive:screen-height) edges buflist))))
 
 (defmacro revive:get-file (x)
   (list 'car x))
@@ -569,9 +563,7 @@ property list is formed as
 		      (find-file file)
 		    (ftp-error (error "Maybe you made mistake twice.")))))
 	       (current-buffer))))
-   (t nil)
-   )
-)
+   (t nil)))
 
 ;;;###autoload
 (defun restore-window-configuration (config)
@@ -599,8 +591,7 @@ current-window-configuration-printable."
 	(set-window-start nil (revive:get-window-start buf))
 	(goto-char (revive:get-point buf))))
       (setq buflist (cdr buflist))
-      (other-window 1)))
-)
+      (other-window 1))))
 
 ;;;	
 (defun revive:buffer-list ()
@@ -618,16 +609,14 @@ current-window-configuration-printable."
   "Wipe Emacs."
   (interactive)
   (save-some-buffers)
-  (mapcar (function kill-buffer) (revive:buffer-list))
-)
+  (mapcar (function kill-buffer) (revive:buffer-list)))
 
 (defun revive:varlist (var2save)
   "Return the (variable . value) list of variables in VAR2SAVE."
   (delq nil (mapcar 
 	     (function (lambda (s)
 			 (if (and s (boundp s)) (cons s (symbol-value s)))))
-	     var2save))
-)
+	     var2save)))
 
 (defun revive:map-string-match (string alist)
   "Return sub-list if a car component of list in ALIST matches STRING.
@@ -640,8 +629,7 @@ That car component is regexp."
 		 (stringp regex)
 		 (string-match (car (car alist)) string))
 	    (throw 'match t))
-	(setq alist (cdr alist)))))
-)
+	(setq alist (cdr alist))))))
 
 (defvar revive:buffer-property-list-hook nil
   "*Evaluated at the beginning of revive:buffer-property-list.")
@@ -683,8 +671,8 @@ Variable-List is a return value of revive:varlist."
 		      (append local-var (assq major-mode mode-local-var)))
 		     )))))
 	(setq buflist (cdr buflist))))
-    (list plist (revive:varlist revive:save-variables-global)))
-)
+    (list plist (revive:varlist revive:save-variables-global))))
+
 (defmacro revive:prop-file-name (x)
   (list 'car x))
 (defmacro revive:prop-buffer-name (x)
@@ -697,6 +685,8 @@ Variable-List is a return value of revive:varlist."
   (list 'nth 4 x))
 (defmacro revive:prop-varlist (x)
   (list 'nth 5 x))
+(defmacro revive:prop-get-value (x y)
+  (list 'cdr (list 'assq y (list 'nth 5 x))))
 
 ;;;###autoload
 (defun save-current-configuration (&optional num)
@@ -721,17 +711,14 @@ Variable-List is a return value of revive:varlist."
     (if (not (bolp)) (newline 1))
     (insert (format "%s\n" (prin1-to-string (list num bufs config))))
     (basic-save-buffer)
-    (kill-buffer (current-buffer))
-    )
-)
+    (kill-buffer (current-buffer))))
 
 (defun revive:restore-value (vlist)
   "Restore variables in VLIST which is a return value of revive:varlist."
   (while vlist
     (if (and (car vlist) (listp (car vlist)))
 	(set (car (car vlist)) (cdr (car vlist))))
-    (setq vlist (cdr vlist)))
-)
+    (setq vlist (cdr vlist))))
 
 (defvar revive:restore-buffers-hook nil
   "*Run at the end of revive:restore-buffers.")
@@ -769,8 +756,7 @@ Variable-List is a return value of revive:varlist."
 	(goto-char (revive:prop-point x))
 	(revive:restore-value (revive:prop-varlist x))))
       (setq blist (cdr blist)))
-    (run-hooks 'revive:restore-buffers-hook))
-)
+    (run-hooks 'revive:restore-buffers-hook)))
 
 (defvar resume-hook nil "*Run at the end of resume.")
 ;;;###autoload
@@ -801,8 +787,7 @@ Configuration should be saved by save-current-configuration."
     (kill-buffer (current-buffer))
     (revive:restore-buffers bufs)
     (restore-window-configuration config)
-    (run-hooks 'resume-hook))
-)
+    (run-hooks 'resume-hook)))
 
 
 ;;;
@@ -819,8 +804,8 @@ Configuration should be saved by save-current-configuration."
 		 (cdr (assq 'dired-actual-switches (revive:prop-varlist x))))
 	  (setq default-directory dir)
 	  (cd dir))
-      (error "Directory [%s] not found" dir)))
-)
+      (error "Directory [%s] not found" dir))))
+
 (defun revive:view ()
   "Restore view-mode's buffer."
   (interactive)
@@ -836,8 +821,8 @@ Configuration should be saved by save-current-configuration."
 	"Skip view-modes' buffer since your view.el may use recursive-edit."))
       (kill-buffer nil)
       (put 'revive:view 'warning t)
-      (sit-for 5)))
-)
+      (sit-for 5))))
+
 (defun revive:mh ()
   "Restore mh-e's buffer."
   (interactive)
@@ -850,8 +835,8 @@ Configuration should be saved by save-current-configuration."
 	default-directory
 	(or (cdr (assq 'default-directory (revive:prop-varlist x)))
 	    "~/"))
-  (cd default-directory)
-)
+  (cd default-directory))
+
 (defun revive:mew ()
   "Restore mew's summary buffer."
   (interactive)
@@ -864,8 +849,15 @@ Configuration should be saved by save-current-configuration."
       (and (fboundp 'mew-init) (let (mew-demo) (mew-init))))
   (mew-cache-flush)			;Mew should take more care of 
   (get-buffer-create " *mew tmp*")	;unexisting buffer...
-  (mew-summary-folder-create (revive:prop-buffer-name x))
-)
+  (let ((b (revive:prop-buffer-name x)))
+    (cond
+     ((fboundp 'mew-summary-folder-create)
+      (mew-summary-folder-create b))
+     ((fboundp 'mew-summary-switch-to-folder)
+      (kill-buffer b)
+      (mew-summary-switch-to-folder b))
+     (t nil))))
+
 (defun revive:shell ()
   "Restore shell-mode's buffer."
   (interactive)
@@ -875,14 +867,50 @@ Configuration should be saved by save-current-configuration."
 	      ".")))
     (shell)
     (cd default-directory)
-    (kill-buffer " *tmp*"))
+    (kill-buffer " *tmp*")))
+
+(defun revive:mpg123 ()
+  "Restore mpg123-mode's buffer."
+  (interactive)
+  (let (d (cdr (assq 'default-directory (revive:prop-varlist x))))
+    (if (and d (file-directory-p d))
+	(progn
+	  (require 'mpg123)
+	  (mpg123 d)))))
+
+(defun revive:c-set-style ()
+  "Restore c-style of C/C++/Java(by cc-mode)."
+  (interactive)
+  (require 'cc-mode)
+  (revive:find-file (revive:prop-file-name x))
+  (funcall (revive:prop-major-mode x))
+  (c-set-style (or (revive:prop-get-value x 'c-indentation-style) "gnu"))
 )
+
 ;;(provide 'resume)
 (provide 'revive)
 
 
-;; $Id: revive.el,v 2.13 1998/04/01 03:52:08 yuuji Exp yuuji $
+;; $Id: revive.el,v 2.18 2003/06/22 05:11:46 yuuji Exp $
 ;; $Log: revive.el,v $
+;; Revision 2.18  2003/06/22 05:11:46  yuuji
+;; revive:c-set-style disabled.
+;;
+;; Revision 2.17  2003/06/13 09:27:56  yuuji
+;; Use window-pixel-edges on XEmacs only (Thanks to sasaki@fcc.ad.jp)
+;;
+;; Revision 2.17  2003/06/13 09:25:02  yuuji
+;; Use window-pixel-edges on XEmacs only (Thanks to sasaki@fcc.ad.jp)
+;;
+;; Revision 2.16  2003/05/16 16:47:52  yuuji
+;; revive:c-set-style fixed
+;;
+;; Revision 2.15  2001/11/21 13:51:24  yuuji
+;; Support mew2
+;;
+;; Revision 2.14  1999/08/26 07:27:52  yuuji
+;; mpg123.el now revivable.
+;;
 ;; Revision 2.13  1998/04/01 03:52:08  yuuji
 ;; FSF's Address fixed
 ;;
