@@ -1,8 +1,8 @@
 ;;; -*- Emacs-Lisp -*-
 ;;; Window manager for GNU Emacs.
-;;; $Id: windows.el,v 2.26 1999/05/14 05:43:38 yuuji Exp $
-;;; (c) 1993-1999 by HIROSE Yuuji [yuuji@gentei.org]
-;;; Last modified Fri May 14 14:35:14 1999 on firestorm
+;;; $Id: windows.el,v 2.39 2003/03/28 11:34:41 yuuji Exp $
+;;; (c) 1993-2002 by HIROSE Yuuji [yuuji@gentei.org]
+;;; Last modified Fri Mar 28 20:30:41 2003 on firestorm
 
 ;;;		Window manager for GNU Emacs
 ;;;
@@ -13,10 +13,11 @@
 ;;;	style  of  window division,  you  may have  your  own  style  of
 ;;;	partitioning.   But  if you  switch the  mode to  e-mail mode or
 ;;;	NetNews mode, they break your favorite style.
+;;;	
 ;;;	  Windows.el  enables  you  to  have  multiple  favorite  window
-;;;	configurations at the  same time, and switch them.  Furthermore,
-;;;	it can save all window  configurations into a  file and  restore
-;;;	them correctly.
+;;;	configurations at the same  time, and switch them.  Furthermore,
+;;;	it  can  save  all  window  configurations and  some  global  or
+;;;	buffer-local variables into a file and restore them correctly.
 ;;;
 ;;;  **For Emacs 19 or later**
 ;;;
@@ -303,269 +304,276 @@
 ;;;
 ;;; Japanese Document follows:
 ;;;
-;;;		GNU Emacs $BMQJT=82hLL%^%M!<%8%c(B [windows]
+;;;		GNU Emacs Խ̥ޥ͡ [windows]
 ;;;
-;;;$B!Z$G$-$k;v![(B
+;;;ڤǤ
 ;;;
-;;;	  GNU Emacs $B$G$O=D2#G$0U$N?t$@$1%&%#%s%I%&$rJ,3d$7$F:n6H$r$9$k;v(B
-;;;	$B$,$G$-$^$9!#%W%m%0%i%`$r3+H/$9$k;~$J$I$N%&%#%s%I%&J,3d$O8zN($KBg(B
-;;;	$B$-$/1F6A$9$k$N$G!"?M$K$h$C$F9%$_$NJ,3d7ABV$r;}$C$F$$$k;v$G$7$g$&!#(B
-;;;	$B$7$+$7$=$NESCf$G!"%a%$%k$d%K%e!<%9$rFI$`$H$=$NJ,3d7ABV$r2u$5$l$F(B
-;;;	$B$7$^$$$^$9!#@5$7$$<j=g$G%a%$%k%j!<%@%b!<%I$r=*$o$l$PNI$$$N$G$9$,!"(B
-;;;	$B$=$l$@$H$^$?%a%$%k$,Mh$?;~$K:F$S%a%$%k%j!<%@%b!<%I$r5/F0$7$J$1$l(B
-;;;	$B$P$J$j$^$;$s!#(B
-;;;	  windows.el $B$r%m!<%I$9$k$H!"9%$_$N%&%#%s%I%&J,3d7ABV$rJ#?t;}$A!"(B
-;;;	$B$=$l$i$r@ZBX$($J$,$i(B Emacs $B$r;H$&;v$,$G$-$^$9!#$5$i$K!"$=$NJ,3d(B
-;;;	$B7ABV$NA4$F$r%U%!%$%k$K%;!<%V$7!"$$$D$G$b$=$l$i$rI|85$9$k$3$H$,$G(B
-;;;	$B$-$^$9!#(B
+;;;	  GNU Emacs ǤϽĲǤդοɥʬ䤷ƺȤ򤹤
+;;;	ǤޤץȯʤɤΥɥʬϸΨ
+;;;	ƶΤǡͤˤäƹߤʬ֤äƤǤ礦
+;;;	ǡᥤ˥塼ɤȤʬ֤
+;;;	ޤޤǥᥤ꡼⡼ɤ򽪤ɤΤǤ
+;;;	Ȥޤᥤ뤬褿˺Ƥӥᥤ꡼⡼ɤưʤ
+;;;	Фʤޤ
+;;;	  windows.el ɤȡߤΥɥʬ֤ʣ
+;;;	ؤʤ Emacs ȤǤޤˡʬ
+;;;	֤Ƥե˥֤ĤǤ⤽뤳Ȥ
+;;;	ޤ
 ;;;
-;;;	  Emacs 19(Mule2) $B0J9_$G$O!"F1MM$NA`:nBN7O$G(B frame $B$rC10L$H$7$F(B
-;;;	$B%&%#%s%I%&@ZBX$(A`:n$r9T$$$^$9!#$5$i$KJ,3d7ABVI|85;~$K$O%U%l!<%`(B
-;;;	$B$N%5%$%:$H0LCV$bCi<B$K:F8=$7$^$9!#%U%l!<%`$N7y$$$J?M$OJQ?t$N@_Dj(B
-;;;	$B$K$h$j%U%l!<%`$r;H$o$J$$%&%#%s%I%&$N@Z$jBX$($GMxMQ$9$k$3$H$b$G$-(B
-;;;	$B$^$9!#(B
+;;;	  Emacs 19(Mule2) ʹߤǤϡƱͤηϤ frame ñ̤Ȥ
+;;;	ɥؤԤޤʬˤϥե졼
+;;;	ΥȰ֤¤˺Ƹޤե졼ηʿͤѿ
+;;;	ˤե졼ȤʤɥڤؤѤ뤳ȤǤ
+;;;	ޤ
 ;;;
-;;;$B!Z=`Hw![(B
+;;;ڽ
 ;;;
-;;;	  windows.el $B$r(B load-path $B$NDL$C$?%G%#%l%/%H%j$KF~$l$F$/$@$5$$!#(B
-;;;	$B$=$7$F0J2<$N9T$r(B .emacs $B$KF~$l$F$/$@$5$$!#(B
+;;;	  windows.el  load-path ̤äǥ쥯ȥƤ
+;;;	ưʲιԤ .emacs Ƥ
 ;;;
 ;;;	   (require 'windows)
 ;;;	   (define-key global-map "\C-xC" 'see-you-again)
 ;;;	   (win:startup-with-window)
 ;;;
 ;;;
-;;;$B!Z%-!<Dj5A![(B
+;;;ڥ
 ;;;
-;;;	  $B%G%U%)%k%H$N%W%j%U%#%/%9%-!<$O(B C-c C-w $B$G$9!#$3$l$G$OITET9g$J(B
-;;;	$B>l9g$O!X%-!<%+%9%?%^%$%:!Y$N9`$r;2>H$7$F$/$@$5$$!#I8=`>uBV$N%-!<(B
-;;;	$B%P%$%s%I$O0J2<$N$h$&$K$J$C$F$$$^$9!#(B
+;;;	  ǥեȤΥץե C-c C-w ǤǤԹ
+;;;	ϡإޥ٤ι򻲾ȤƤɸ֤Υ
+;;;	ХɤϰʲΤ褦ˤʤäƤޤ
 ;;;
-;;;		C-c C-w 1	$BJ,3d>uBV(B 1 $B$X(B (Q)
-;;;		C-c C-w 2	$BJ,3d>uBV(B 2 $B$X(B (Q)
+;;;		C-c C-w 1	ʬ 1  (Q)
+;;;		C-c C-w 2	ʬ 2  (Q)
 ;;;		   :
-;;;		C-c C-w 9	$BJ,3d>uBV(B 9 $B$X(B (Q)
-;;;		C-c C-w 0	$BD>A0$NJ,3d>uBV$X(B($B%P%C%U%!(B0$B$H8r49(B) (Q)
-;;;		C-c C-w SPC	$BJ,3d>uBV(B1$B!A(Bn$B$N$&$A!"D>A0MQ$$$?$b$N$X(B (Q)
-;;;		C-c C-w n	$B<!$NJ,3d>uBV$X(B(C-c SPC)
-;;;		C-c C-w p	$BA0$NJ,3d>uBV$X(B
-;;;		C-c C-w !	$B8=:_$N%&%#%s%I%&$rGK4~(B (Q)
-;;;		C-c C-w C-w	$B%&%#%s%I%&A`:n%a%K%e!<(B
-;;;		C-c C-w C-r	$B%j%8%e!<%`%a%K%e!<(B
-;;;		C-c C-w C-l	$B%m!<%+%k%j%8%e!<%`%a%K%e!<(B
-;;;		C-c C-w C-s	$B%?%9%/@ZBX$((B
-;;;		C-c C-w =	$BJ,3d>uBVJ]B8%P%C%U%!0lMwI=<((B (Q)
+;;;		C-c C-w 9	ʬ 9  (Q)
+;;;		C-c C-w 0	ľʬ֤(Хåե0ȸ) (Q)
+;;;		C-c C-w SPC	ʬ1nΤľѤΤ (Q)
+;;;		C-c C-w n	ʬ֤(C-c SPC)
+;;;		C-c C-w p	ʬ֤
+;;;		C-c C-w !	ߤΥɥ˴ (Q)
+;;;		C-c C-w -	äΥɥ֤(Q)
+;;;		C-c C-w C-w	ɥ˥塼
+;;;		C-c C-w C-r	ꥸ塼˥塼
+;;;		C-c C-w C-l	ꥸ塼˥塼
+;;;		C-c C-w C-s	ؤ
+;;;		C-c C-w =	ʬ¸Хåեɽ (Q)
 ;;;
-;;;	  1 $BHV$+$i(B 9 $BHV$^$G$N%&%#%s%I%&A*Br$OHs>o$KIQHK$KMQ$$$i$l$k$N$G!"(B
-;;;	$B!V(BC-c $BHV9f!W$G$b@Z$jBX$($,$G$-$k$h$&$K$J$C$F$$$^$9(B($B$=$NB>(BQ$B%^!<%/(B
-;;;	$B$NIU$$$F$$$k%-!<%P%$%s%IA4$F$O(B C-w $B$rBG$?$J$/$F$b$h$$(B)$B!#$3$l$rL5(B
-;;;	$B8z$K$9$k$?$a$K$O!"(B~/.emacs $B$J$I$GJQ?t(B win:quick-selection $B$r(B nil 
-;;;	$B$K%;%C%H$7$F$/$@$5$$!#(B
+;;;	  1 ֤ 9 ֤ޤǤΥɥˤѤΤǡ
+;;;	C-c ֹפǤڤؤǤ褦ˤʤäƤޤ(¾Qޡ
+;;;	դƤ륭ХƤ C-w ǤʤƤ褤)̵
+;;;	ˤ뤿ˤϡ~/.emacs ʤɤѿ win:quick-selection  nil 
+;;;	˥åȤƤ
 ;;;
-;;;$B!Z@bL@![(B
 ;;;
-;;;	  windows.el $B$K$O(B0$B$+$i(B9$B$^$G$N(B10$B8D$N%P%C%U%!$,MQ0U$5$l$F$$$^$9!#(B
-;;;	$B$3$N$&$A%f!<%6$,9%$_$NJ,3d>uBV$rJ]B8$5$;$k$?$a$K;H$($k$N$O(B1$B!A(B9 
-;;;	$B$G!"(B0$BHV$O<+F0E*$KD>A0$NJ,3d>uBV$r%;!<%V$9$k$?$a$K;H$o$l$^$9(B
-;;;	(Emacs-19$B0J9_$G$O(Bwindows$B$K3d$jEv$F$i$l$F$$$J$$(Bframe$B$X$N%8%c%s%W(B)$B!#(B
 ;;;
-;;;	  win:startup-with-window $B$r(B .emacs $B$K=q$$$F$$$k>l9g$O5/F0;~$NJT(B
-;;;	$B=8>uBV$,$=$N$^$^(B1$BHV$N%P%C%U%!$K3JG<$5$l$F$$$^$9!#$=$&$G$J$$>l9g(B
-;;;	$B$O2?$+(B C-c C-w 1 $B$r2!$7$F:G=i$NJT=8>uBV$r(B1$BHV$N%P%C%U%!$K5-21$5$;(B
-;;;	$B$^$9!#(B
+;;;	  windows.el ˤ09ޤǤ10ĤΥХåեѰդƤޤ
+;;;	Τ桼ߤʬ֤¸뤿˻ȤΤ19 
+;;;	ǡ0֤ϼưŪľʬ֤򥻡֤뤿˻Ȥޤ
+;;;	(Emacs-19ʹߤǤwindows˳ƤƤʤframeؤΥ)
 ;;;
-;;;	  $B$5$F!"(B1$BHV$K8=>u$rJ]B8$7$?>uBV$G!"%a%$%k$rFI$_$^$7$g$&!#%a%$%k(B
-;;;	$B$O(B2$BHV$N%&%#%s%I%&$K3d$jEv$F$^$9!#(BC-c C-w 2 $B$r2!$9$H:#EY$O(B
+;;;	  win:startup-with-window  .emacs ˽񤤤Ƥϵư
+;;;	֤Τޤ1֤ΥХåե˳ǼƤޤǤʤ
+;;;	ϲ C-c C-w 1 򲡤ƺǽԽ֤1֤ΥХåե˵
+;;;	ޤ
+;;;
+;;;	  ơ1֤˸¸֤ǡᥤɤߤޤ礦ᥤ
+;;;	2֤Υɥ˳ƤޤC-c C-w 2 򲡤Ⱥ٤
 ;;;
 ;;;		C)reate D)uplicate P)reserve F)indfile B)uff X)M-x N)o:
 ;;;
-;;;	$B$H=P$FMh$^$9(B($B$3$l$r%&%#%s%I%&@8@.%a%K%e!<$H8F$V$3$H$K$7$^$9(B)$B!#%a(B
-;;;	$B%$%k$rFI$`$?$a$K$O8=:_$NJ,3d>uBV$OI,MW$"$j$^$;$s$+$i!"(BCreate $B$N(B 
-;;;	c $B$r2!$7$F?75,%&%#%s%I%&$r:n@.$7$^$9!#$=$3$G%a%$%k%j!<%@$r5/F0$9(B
-;;;	$B$k$H!"%&%#%s%I%&$NJ,3d>uBV$,%a%$%k@lMQ$K$J$j$^$9(B($B$b$A$m$s%a%K%e!<(B
-;;;	$B$G(Bx$B$r2!$7$FD>@\%a%$%k%j!<%@$r5/F0$7$F$b$+$^$$$^$;$s(B)$B!#FI$_=*$o$C(B
-;;;	$B$?$i(B C-c C-w 1 $B$r2!$9$H!"(B1$BHV$N%P%C%U%!$KJ]B8$5$l$F$$$k!":G=i$N%W(B
-;;;	$B%m%0%i%`JT=8>uBV$K@Z$jBX$o$j$^$9!#$3$l$G%W%m%0%i%`:n@.$KD>$A$KLa(B
-;;;	$B$l$^$9!#(B
+;;;	ȽФޤ(򥦥ɥ˥塼ȸƤ֤Ȥˤޤ)
+;;;	ɤिˤϸߤʬ֤ɬפޤ󤫤顢Create  
+;;;	c 򲡤ƿɥޤǥᥤ꡼ư
+;;;	ȡɥʬ֤ᥤѤˤʤޤ(˥塼
+;;;	x򲡤ľܥᥤ꡼ưƤ⤫ޤޤ)ɤ߽
+;;;	 C-c C-w 1 򲡤ȡ1֤ΥХåե¸Ƥ롢ǽΥ
+;;;	Խ֤ڤؤޤǥץľ
+;;;	ޤ
 ;;;
-;;;	  $B:#EY$O%K%e!<%9$rFI$_$^$7$g$&!#(BM-x gnus $B!&!&!&!#$O$$FI$_=*$o$j(B
-;;;	$B$^$7$?!#$$$^$^$G$O(B q $B$G=*N;$7$F$$$^$7$?$,!":#F|$+$i$O0c$$$^$9!#(B 
-;;;	C-c C-w 1 $B$GI|5"$G$-$k$N$G$9!#$O$$!"(BC-c C-w 1$B!#$*$C$H!"?75,%&%#(B
-;;;	$B%s%I%&$r:n@.$9$k$N$rK:$l$F$$$?$N$G!"$^$@(B1$BHV$N%&%#%s%I%&$K$$$?$N(B
-;;;	$B$G$7$?!#$3$N$^$^(B(%1)$B$G$O$;$C$+$/(B1$BHV$KJ]B8$7$?%W%m%0%i%`JT=8>uBV(B
-;;;	$B$,>C$($F$7$^$$$^$9!#$=$s$J;~$O!"(BC-c C-w 3 $B$r2!$7$F%&%#%s%I%&@8@.(B
-;;;	$B%a%K%e!<$,=P$?$H$3$m$G!"(BPreserve $B$N(B p $B$r2!$7$F$/$@$5$$!#(B1$BHV$N%P%C(B
-;;;	$B%U%!$NFbMF$O99?7$;$:$K!"8=>u$N%&%#%s%I%&>uBV$r(B3$BHV$N%P%C%U%!$KJ](B
-;;;	$BB8$7$^$9!#(B
-;;;   **Mule2$B$G$O%j%8%e!<%`(B($B8e=R(B)$B%U%!%$%k$K8=:_$N>uBV$,%;!<%V$5$l$F$$$J(B
-;;;	$B$$8B$j!"J,3d>uBV$rI|5l$9$k$3$H$,$G$-$^$;$s!#(B
+;;;	  ٤ϥ˥塼ɤߤޤ礦M-x gnus Ϥɤ߽
+;;;	ޤޤޤǤ q ǽλƤޤϰ㤤ޤ 
+;;;	C-c C-w 1 ǤΤǤϤC-c C-w 1äȡ
+;;;	ɥΤ˺ƤΤǡޤ1֤Υɥˤ
+;;;	ǤΤޤ(%1)ǤϤä1֤¸ץԽ
+;;;	äƤޤޤʻϡC-c C-w 3 򲡤ƥɥ
+;;;	˥塼ФȤǡPreserve  p 򲡤Ƥ1֤ΥХ
+;;;	եƤϹˡΥɥ֤3֤ΥХåե
+;;;	¸ޤ
+;;;   **Mule2Ǥϥꥸ塼()ե˸ߤξ֤֤Ƥ
+;;;	¤ꡢʬ֤줹뤳ȤǤޤ
 ;;;
-;;;	  $B$"$H$O%a%$%k$,Mh$?$i(B C-c C-w 2 $B$r!"%W%m%0%i%`$KK0$-$?$i(B C-c
-;;;	C-w 3 $B$r2!$7$F0lF|$r2a$4$7$^$7$g$&!#%a%$%k$H%K%e!<%9$@$1$rFI$_B3(B
-;;;	$B$1$k>l9g$N$h$&$KFs$D$N>uBV$r9T$C$?$jMh$?$j$9$k>l9g$O(B C-c C-w SPC 
-;;;	$B$,JXMx$G$9!#(B
+;;;	  Ȥϥᥤ뤬褿 C-c C-w 2 򡢥ץ˰ C-c
+;;;	C-w 3 򲡤ưᤴޤ礦ᥤȥ˥塼ɤ³
+;;;	Τ褦Ĥξ֤Ԥä褿ꤹ C-c C-w SPC 
+;;;	Ǥ
 ;;;
-;;;	  $B!V$"$l!"%a%$%k$O$$$^2?HV$N%&%#%s%I%&$@(B?$B!W$HJ,$+$i$J$/$J$C$?$i!"(B
-;;;	C-c C-w = $B$r2!$7$^$7$g$&!#%_%K%P%C%U%!$KHV9f$H!"BP1~$9$k%P%C%U%!(B
-;;;	$BL>$,%a%K%e!<%P%C%U%!$KI=<($5$l$^$9!#$3$N$&$A!"(B $B%P%C%U%!L>$NF,$K(B*
-;;;	$B$,IU$$$F$$$k$b$N$,8=:_A*Br$7$F$$$k%P%C%U%!$G!"(B +$B$,IU$$$F$$$k$b$N(B
-;;;	$B$,D>A0$KA*Br$7$F$$$?%P%C%U%!$G$9(B($B$D$^$j(B  C-c C-w SPC $B$N9T$-@h(B)$B!#(B
-;;;	$B%a%K%e!<%P%C%U%!$G$O!"(B n $B$d(B p $B$r2!$7$F@ZBX$($?$$%&%#%s%I%&$N0LCV(B
-;;;	$B$^$G0\$j!"(B SPC $B$G$=$N%&%#%s%I%&$K@ZBX$($k$3$H$,$G$-$^$9!#$^$?(B d,
-;;;	k, s, l $B$r2!$9$H9TF,$K(B D, K,  S, L $B%^!<%/$,IU$-$^$9!#$3$3$G(B x $B$r(B
-;;;	$B2!$9$H%^!<%/$rIU$1$?%P%C%U%!$KBP$7!"$=$l$>$l!V:o=|!W!"!VI=<($5$l(B
-;;;	$B$F$$$k%P%C%U%!$b4^$a$F:o=|(B(kill)$B!W!"!V>uBV$r%U%!%$%k$K%;!<%V!W!"(B
-;;;	$B!V>uBV$r%U%!%$%k$+$i%m!<%I!W$r9T$$$^$9!#>\$7$/$O!"%a%K%e!<%P%C%U%!(B
-;;;	$B$G(B ? $B$r2!$7$F$/$@$5$$!#(B
+;;;	  ֤졢ᥤϤ޲֤Υɥ?פʬʤʤä顢
+;;;	C-c C-w = 򲡤ޤ礦ߥ˥ХåեֹȡбХåե
+;;;	̾˥塼ХåեɽޤΤ Хåե̾Ƭ*
+;;;	դƤΤ򤷤ƤХåեǡ +դƤ
+;;;	ľ򤷤ƤХåեǤ(Ĥޤ  C-c C-w SPC ιԤ)
+;;;	˥塼ХåեǤϡ n  p 򲡤ؤɥΰ
+;;;	ޤǰܤꡢ SPC ǤΥɥؤ뤳ȤǤޤޤ d,
+;;;	k, s, l 򲡤ȹƬ D, K,  S, L ޡդޤ x 
+;;;	ȥޡդХåեФ줾ֺסɽ
+;;;	ƤХåեޤƺ(kill)ס־֤ե˥֡ס
+;;;	־֤ե뤫ɡפԤޤܤϡ˥塼Хåե
+;;;	 ? 򲡤Ƥ
 ;;;
 ;;;	(%1)
-;;;	$B$3$N>uBV$G$O%P%C%U%!$K%W%m%0%i%`JT=8>uBV$,J]B8$5$l!"%&%#%s%I%&$K(B
-;;;	GNUS$B$N2hLL$,I=<($5$l$F$$$k!#$J$*!"(BPreserve $B$O(B Emacs 19 $B$G(Bframe$B$r(B
-;;;	$B@ZBX$(C10L$H$9$k>l9g$K$OMxMQ$G$-$J$$$N$GCm0U$7$F2<$5$$!#(B
+;;;	ξ֤ǤϥХåե˥ץԽ֤¸졢ɥ
+;;;	GNUSβ̤ɽƤ롣ʤPreserve  Emacs 19 frame
+;;;	ؤñ̤ȤˤѤǤʤΤդƲ
 ;;;
-;;;$B!Z$=$NB>:Y$+$$5!G=![(B
+;;;ڤ¾٤ǽ
 ;;;
-;;;	  C-c C-w C-w $B$r2!$9$H0J2<$N$h$&$J%a%K%e!<$,=P$FMh$^$9!#(B
+;;;	  C-c C-w C-w 򲡤ȰʲΤ褦ʥ˥塼Фޤ
 ;;;
 ;;;	N)ext P)rev R)ecent D)elete K)ill S)ave2buf L)oad-from-buf A)save-As
 ;;;
-;;;	n, p $B$O$=$l$>$l0l$DA0(B/$B<!$N%P%C%U%!$NA*Br$7$^$9!#(Br $B$O%&%#%s%I%&@Z(B
-;;;	$B$jBX$($9$kD>A0$KI=<($7$F$$$?2hLL$XI|5"$7$^$9(B(%2)$B!#(Bd $B$O8=:_A*Br$7(B
-;;;	$B$F$$$kHV9f$N%P%C%U%!$r>C5n$7$^$9!#(Bk $B$O(B d $B$HF1$8$G$9$,!"8=:_8+$((B
-;;;	$B$F$$$k%U%!%$%k$bF1;~$K%/%m!<%:$7$^$9!#(Bl $B$O4V0c$($F(B C-x 1 $B$7$F$7(B
-;;;	$B$^$C$?;~$J$I$K!"%P%C%U%!$K%;!<%V$5$l$F$$$k%&%#%s%I%&>uBV$r6/@)E*(B
-;;;	$B$KFI$_D>$9;~$K;H$$$^$9!#(Bs $B$O8=:_8+$F$$$k>uBV$r6/@)E*$KBP1~$9$k%P%C(B
-;;;	$B%U%!$K%;!<%V$9$k0Y$K;H$$!"(Ba $B$O%;!<%V$9$k%P%C%U%!HV9f$rJLES;XDj$9(B
-;;;	$B$k;~$K;H$$$^$9!#(B
+;;;	n, p Ϥ줾/ΥХåե򤷤ޤr ϥɥ
+;;;	ؤľɽƤ̤ޤ(%2)d ϸ
+;;;	ƤֹΥХåեõޤk  d ƱǤ߸
+;;;	ƤեƱ˥ޤl ϴְ㤨 C-x 1 Ƥ
+;;;	ޤäʤɤˡХåե˥֤Ƥ륦ɥ֤Ū
+;;;	ɤľ˻Ȥޤs ϸ߸Ƥ֤ŪбХ
+;;;	ե˥֤٤˻Ȥa ϥ֤Хåեֹӻꤹ
+;;;	˻Ȥޤ
 ;;;
 ;;;	(%2)
-;;;	Emacs 19 $B$N(B frame $B5!G=$G%&%#%s%I%&@ZBX$($r9T$&>l9g!"D>A0$N>uBV$r(B
-;;;	$BJ]B8$9$k;v$O$G$-$J$$$?$a!"(Br $B$r2!$7$?>l9g(B($B4X?t(Bwin-recent-window)
-;;;	windows $BMQ$K3d$jEv$F$i$l$F$$$J$$(B frame $B$,$"$l$P$=$l$KI=<($r@ZBX(B
-;;;	$B$($^$9(B(C-c C-w 0 $B$HF1$8(B)$B!#(B
+;;;	Emacs 19  frame ǽǥɥؤԤ硢ľξ֤
+;;;	¸ϤǤʤᡢr 򲡤(ؿwin-recent-window)
+;;;	windows Ѥ˳ƤƤʤ frame Фɽ
+;;;	ޤ(C-c C-w 0 Ʊ)
 ;;;
-;;;	  $B?75,%&%#%s%I%&:n@.;~$K!"8=:_$N%P%C%U%!FbMF$N99?7$H!"?7%&%#%s%I(B
-;;;	$B%&$N>uBV$r;X<($9$k$?$a$K%&%#%s%I%&@8@.%a%K%e!<$,=P$^$9!#$3$l$i$N(B
-;;;	$B0UL#$O0J2<$N$h$&$K$J$C$F$$$^$9!#(B
+;;;	  ɥˡߤΥХåեƤιȡ
+;;;	ξ֤ؼ뤿˥ɥ˥塼Фޤ
+;;;	̣ϰʲΤ褦ˤʤäƤޤ
 ;;;
-;;;		Create		$B8=2hLL$r8=%P%C%U%!$KJ]B88e!"?75,%&%#%s%I(B
-;;;				$B%&$r@8@.(B
-;;;		Duplicate	$B8=2hLL$r8=%P%C%U%!$KJ]B88e!"8=2hLL$HF1$8(B
-;;;				$B%&%#%s%I%&$r@8@.(B
-;;;		Preserve	$B8=%P%C%U%!$O99?7$;$:!"8=2hLL$r?75,%&%#%s(B
-;;;				$B%I%&$H$7$FEPO?(B
-;;;		Findfile	$B?75,%&%#%s%I%&$G(B find-file $B$r9T$J$&(B
-;;;		Buff		$B?75,%&%#%s%I%&$G(B switch-to-buffer $B$r9T$J$&(B
-;;;		M-x		$B?75,%&%#%s%I%&$G%3%^%s%I<B9T(B
-;;;		No		$B?75,%&%#%s%I%&@8@.$rCf;_(B
+;;;		Create		̤򸽥Хåե¸塢
+;;;				
+;;;		Duplicate	̤򸽥Хåե¸塢̤Ʊ
+;;;				ɥ
+;;;		Preserve	ХåեϹ̤򿷵
+;;;				ɥȤϿ
+;;;		Findfile	ɥ find-file Ԥʤ
+;;;		Buff		ɥ switch-to-buffer Ԥʤ
+;;;		M-x		ɥǥޥɼ¹
+;;;		No		ɥ
 ;;;
-;;;$B!Z%j%8%e!<%`![(B
+;;;ڥꥸ塼
 ;;;
-;;;	  revive.el $B$HAH$_9g$o$;$F;H$&$3$H$K$h$j!"%j%8%e!<%`5!G=$,M-8z$G(B
-;;;	$B$9!#(BC-c C-w C-r $B$r2!$9$H0J2<$N%a%K%e!<$,8=$l$^$9!#(B
+;;;	  revive.el Ȥ߹碌ƻȤȤˤꡢꥸ塼ൡǽͭ
+;;;	C-c C-w C-r 򲡤ȰʲΥ˥塼ޤ
 ;;;
 ;;;	     A)save-all R)estore-all S)ave-this L)oad-this N)Load# ~)read-~
 ;;;
-;;;	$B$3$3$G(B a $B$r2!$9$H8=:_$NA4$F$N%&%#%s%I%&$N>pJs$r%U%!%$%k$K%;!<%V(B
-;;;	$B$9$k$3$H$,$G$-$^$9!#(Br $B$r2!$9$H%U%!%$%k$K%;!<%V$7$?$b$N$r%m!<%I$9(B
-;;;	$B$k$3$H$,$G$-$^$9!#(Bs,l $B$r2!$9$H8=:_A*Br$7$F$$$k%&%#%s%I%&>uBV$r$=(B
-;;;	$B$l$>$l(B $B%;!<%V(B/$B%m!<%I(B $B$7$^$9!#(Bn $B$O%U%!%$%k$+$i?t;z$G;XDj$7$?%&%#(B
-;;;	$B%s%I%&>uBV$r%m!<%I$7$^$9!#$^$?(B Emacs $B5/F0D>8e$K(B r $B$r2!$9$H$3$m$r(B
-;;;	$B4V0c$($F(B a $B$r2!$7$F$7$^$C$?>l9g$J$I$O(B ~ $B$rMxMQ$7$F$/$@$5$$!#(B
+;;;	 a 򲡤ȸߤƤΥɥξե˥
+;;;	뤳ȤǤޤr 򲡤ȥե˥֤Τɤ
+;;;	뤳ȤǤޤs,l 򲡤ȸ򤷤Ƥ륦ɥ֤
+;;;	줾 / ޤn ϥե뤫ǻꤷ
+;;;	ɥ֤ɤޤޤ Emacs ưľ r 򲡤Ȥ
+;;;	ְ㤨 a 򲡤Ƥޤäʤɤ ~ ѤƤ
 ;;;
-;;;	  $B$3$N%a%K%e!<$+$i%;!<%V$9$k$h$j$b!V(BC-x C$B!W$G(B Emacs $B$r=*N;$7!"<!(B
-;;;	$B2s(B Emacs $B$r5/F0$7$?D>8e$K(B resume-windows ($B$^$?$O(B C-c C-w C-r r)
-;;;	$B$r5/F0$9$k$3$H$GD>$A$K0JA0$N>uBV$KLa$k$3$H$,$G$-$k$N$G$3$A$i$NJ}(B
-;;;	$B$,JXMx$J;H$$J}$H$$$($^$7$g$&!#(B
+;;;	  Υ˥塼饻֤C-x Cפ Emacs λ
+;;;	 Emacs ưľ resume-windows (ޤ C-c C-w C-r r)
+;;;	ư뤳Ȥľ˰ξ֤뤳ȤǤΤǤ
+;;;	ʻȤȤޤ礦
 ;;;
-;;;$B!Z%m!<%+%k%j%8%e!<%`![(B
+;;;ڥꥸ塼
 ;;;
-;;;	  $B%j%8%e!<%`$G$OA4$F$N%&%#%s%I%&>pJs$r%U%!%$%k$K%;!<%V$7$^$9$,!"(B
-;;;	$B$=$N%U%!%$%k$r$5$i$KJ#?t;}$A!"$=$l$>$l$r@Z$jBX$($F;H$&$3$H$,$G$-(B
-;;;	$B$^$9!#!V(BC-c C-w C-l$B!W$r%?%$%W$7>pJs%U%!%$%k$r%;!<%V(B/$B%m!<%I$9$k%G(B
-;;;	$B%#%l%/%H%j$rF~NO$7$?8e!"DL>o$N%j%8%e!<%`%a%K%e!<$NA`:n$r9T$J$$$^(B
-;;;	$B$9!#(B
+;;;	  ꥸ塼ǤƤΥɥե˥֤ޤ
+;;;	Υե򤵤ʣ줾ڤؤƻȤȤǤ
+;;;	ޤC-c C-w C-lפ򥿥פե򥻡/ɤ
+;;;	쥯ȥϤ塢̾Υꥸ塼˥塼Ԥʤ
+;;;	
 ;;;
-;;;	  $B$H$3$m$G!"B?$/$N;E;v$O$=$N;E;vFCM-$N%G%#%l%/%H%j$r%Y!<%9$K9T$o(B
-;;;	$B$l$^$9!#$3$N@-<A$rMxMQ$7$F!"0lEY$KJ#?t8D$N;E;v$r$3$J$9>l9g$J$I$K!"(B
-;;;	$B4X?t(B win-switch-task $B$r;H$&$H;E;v$N@ZBX$($r%9%`!<%:$K9T$&$3$H$,(B
-;;;	$B$G$-$^$9!#$3$N4X?t$r8F$V$H8=:_$N4D6-$r8=:_$N>pJs%U%!%$%k$KJ]B8$9(B
-;;;	$B$k$+3NG'8e!"<!$N;E;v$r9T$C$F$$$k%G%#%l%/%H%j$NF~NO$rB%$7$^$9!#(B
+;;;	  Ȥǡ¿λŻϤλŻͭΥǥ쥯ȥ١˹Ԥ
+;;;	ޤѤơ٤ʣĤλŻ򤳤ʤʤɤˡ
+;;;	ؿ win-switch-task ȤȻŻؤ򥹥ࡼ˹ԤȤ
+;;;	ǤޤδؿƤ֤ȸߤδĶ򸽺ߤξե¸
+;;;	뤫ǧ塢λŻԤäƤǥ쥯ȥϤ¥ޤ
 ;;;
-;;;$B!Z%+%9%?%^%$%:![(B
+;;;ڥޥ
 ;;;
-;;;	  $B%W%j%U%#%/%9%-!<$rNc$($P(B C-c w $B$KJQ99$9$k;~$O(B .emacs $B$K<!$N$h(B
-;;;	$B$&$J5-=R$r$$$l$^$9!#(B
+;;;	  ץե㤨 C-c w ѹ .emacs ˼Τ
+;;;	ʵҤ򤤤ޤ
 ;;;
 ;;;		(setq win:switch-prefix "\C-cw")
 ;;;		(define-key global-map win:switch-prefix nil)
 ;;;		(define-key global-map "\C-cw1" 'win-switch-to-window)
 ;;;
-;;;	  $B%&%#%s%I%&$NA*Br$r(B1$B!A(B9$B$G$O$J$/$F!"(Ba$B!A(Bz$B$K$9$k$3$H$b$G$-$^$9!#(B
+;;;	  ɥ19ǤϤʤơazˤ뤳ȤǤޤ
 ;;;
 ;;;		(setq win:switch-prefix "\C-cw")
 ;;;		(define-key global-map win:switch-prefix nil)
 ;;;		(define-key global-map "\C-cwa" 'win-switch-to-window)
-;;;		(setq win:base-key ?`)		;; ` $B$O!VD>A0$N>uBV!W(B
-;;;		(setq win:max-configs 27)	;; ` $B!A(B z $B$O(B27$BJ8;z(B
-;;;		(setq win:quick-selection nil)	;; C-c$B1Q;z(B $B$K3d$jEv$F$J$$(B
+;;;		(setq win:base-key ?`)		;; ` ϡľξ֡
+;;;		(setq win:max-configs 27)	;; `  z 27ʸ
+;;;		(setq win:quick-selection nil)	;; C-cѻ ˳Ƥʤ
 ;;;
-;;;	$B$3$3$G(B ` $B$O%"%9%-!<%3!<%I$G(B a $B$N0l$DA0$K$"$k$3$H$KCm0U$7$F$/$@$5(B
-;;;	$B$$!#(BC-c C-w ` $B$OD>A0>uBVJ]B8MQ%P%C%U%!$H!"%+%l%s%H%&%#%s%I%&$NFb(B
-;;;	$BMF$N8r49$K3d$jEv$F$i$l$^$9!#(B
+;;;	 ` ϥɤ a ΰˤ뤳ȤդƤ
+;;;	C-c C-w ` ľ¸ѥХåեȡȥɥ
+;;;	Ƥθ򴹤˳Ƥޤ
 ;;;
-;;;	  windows $B$NF0:n$rD4@0$9$k0J2<$NJQ?t$,$"$j$^$9!#(B
+;;;	  windows ưĴʲѿޤ
 ;;;
-;;;	win:switch-prefix	windows.el $BA`:nMQ$N(Bprefix$B%-!<(B
-;;;	win:menu-key-stroke	window$B@8@.(Bmenu$B$N%-!<(B(prefix$B%-!<$KB3$1$F(B)
-;;;	win:resume-key-stroke	resume menu $B$N%-!<(B ($B!7(B)
-;;;	win:resume-local-key-stroke	local resume menu $B$N%-!<(B ($B!7(B)
-;;;	win:switch-task-key-stroke	switch task menu $B$N%-!<(B ($B!7(B)
-;;;	win:quick-selection	C-c $B?t;z(B $B$J$I$G(Bwindow$BA*Br$G$-$k(B
-;;;	win:mode-line-format	window$BHV9f$r<($9(B mode-line format
-;;;	win:configuration-file	resume file $B$N%Q%9L>(B
-;;;	win:make-backup-files	resume file $B$N%P%C%/%"%C%W$r<h$k$+(B
-;;;	win:buffer-depth-per-win window$BKh$K(Bbuffer-list$B$N>e0L2?8D$r5-21$9$k$+(B
-;;;				nil$B$N;~$O(Bbuffer-list$BM%@h=g0L$rJ]B8$7$J$$(B
+;;;	win:switch-prefix	windows.el Ѥprefix
+;;;	win:menu-key-stroke	windowmenuΥ(prefix³)
+;;;	win:resume-key-stroke	resume menu Υ ()
+;;;	win:resume-local-key-stroke	local resume menu Υ ()
+;;;	win:switch-task-key-stroke	switch task menu Υ ()
+;;;	win:quick-selection	C-c  ʤɤwindowǤ
+;;;	win:mode-line-format	windowֹ򼨤 mode-line format
+;;;	win:configuration-file	resume file Υѥ̾
+;;;	win:make-backup-files	resume file ΥХååפ뤫
+;;;	win:buffer-depth-per-win windowbuffer-listξ̲Ĥ򵭲뤫
+;;;				nilλbuffer-list̤ͥ¸ʤ
+;;;	win:inhibit-switch-in-minibuffer
+;;;				ߥ˥ХåեǤwindowڤؤʤ
+;;;	win:memorize-winconf-timing
+;;;				C-c C-w - ٤ɥ֤
+;;;				¸륿ߥ󥰤ꤹ 'save (ե
+;;;				¸)ޤ 'change (Хåե)
 ;;;
-;;;	-- $B0J2<(B mule2 $B0J9_$G%U%l!<%`$rMxMQ$9$k>l9g$N$_M-8z(B --
-;;;	win:no-raise-at-save	$BA4(Bwindow$B$N%;!<%V;~$K%U%l!<%`$r(Braise$B$9$k$+(B
+;;;	-- ʲ mule2 ʹߤǥե졼ѤΤͭ --
+;;;	win:no-raise-at-save	windowΥֻ˥ե졼raise뤫
 ;;;	win:frame-parameters-to-save-private
-;;;				frame parameter $B$N$&$A%;!<%V$7$?$$%Q%i%a!<(B
-;;;				$B%?(B(win:frame-parameters-to-save-default 
-;;;				$B$NCM0J30$N$b$N$r@_Dj$9$k(B)
-;;;	win:auto-position	$B%U%l!<%`?75,:n@.;~$K(B
-;;;				nil $B$J$i<jF0$G0LCV$r3NDj(B
-;;;				'absolute $B$J$i@dBP:BI8$r7W;;$7$FG[CV(B
-;;;				'relative $B$J$i8=%U%l!<%`$H$NAjBP0LCV$GG[CV(B
-;;;	win:new-frame-offset-x	$B?75,%U%l!<%`<+F0G[CV;~$N(BX$B:BI8$N%*%U%;%C%H(B
-;;;	win:new-frame-offset-y	$B?75,%U%l!<%`<+F0G[CV;~$N(BY$B:BI8$N%*%U%;%C%H(B
-;;;	win:resumed-frame-offset-x $B%U%l!<%`%j%8%e!<%`;~$N(BX$B:BI8$N%*%U%;%C%H(B
-;;;				fvwm$B$N%G%U%)%k%H$N(B BoundaryWidth $B$r;H$&(B
-;;;				$B;~$O$3$NJQ?t$NCM$r(B3$B$K$7$F$*$/$HNI$$!#(B
-;;;	win:resumed-frame-offset-y $B%U%l!<%`%j%8%e!<%`;~$N(BY$B:BI8$N%*%U%;%C%H(B
-;;;	win:mouse-position	$B%U%l!<%`0\F0;~$N%^%&%9%+!<%=%k$N:BI8(B
-;;;				'(x y) $B$H$$$&%j%9%H$G;XDj(B
-;;;	win:frame-title-function $B3F%U%l!<%`$N%?%$%H%k$r7hDj$9$k4X?t(B
-;;;				$B%U%l!<%`HV9f$,0z?t$H$7$FEO$5$l$k!#(B
-;;;				$B$3$NCM$r(Bnil$B$K$9$k$H%?%$%H%k$O$$$8$i$J$$!#(B
+;;;				frame parameter Τ֤ѥ᡼
+;;;				(win:frame-parameters-to-save-default 
+;;;				ͰʳΤΤꤹ)
+;;;	win:auto-position	ե졼࿷
+;;;				nil ʤưǰ֤
+;;;				'absolute ʤкɸ׻
+;;;				'relative ʤ鸽ե졼Ȥа֤
+;;;	win:new-frame-offset-x	ե졼༫ưֻXɸΥեå
+;;;	win:new-frame-offset-y	ե졼༫ưֻYɸΥեå
+;;;	win:resumed-frame-offset-x ե졼ꥸ塼XɸΥեå
+;;;				fvwmΥǥեȤ BoundaryWidth Ȥ
+;;;				Ϥѿͤ3ˤƤɤ
+;;;	win:resumed-frame-offset-y ե졼ꥸ塼YɸΥեå
+;;;	win:mouse-position	ե졼ưΥޥκɸ
+;;;				'(x y) ȤꥹȤǻ
+;;;	win:frame-title-function ƥե졼Υȥꤹؿ
+;;;				ե졼ֹ椬ȤϤ롣
+;;;				ͤnilˤȥȥϤʤ
 ;;;	win:title-with-buffer-name
-;;;				$B%U%l!<%`%?%$%H%k$K%P%C%U%!L>$rIU2C$9$k$+(B
+;;;				ե졼ॿȥ˥Хåե̾ղä뤫
 ;;;
-;;;$B!Z%P%0![(B
+;;;ڥХ
 ;;;
-;;;	  $B%&%#%s%I%&$r@ZBX$($k$H8@$&%"%$%G%"$O(B screen $B%3%^%s%I$K4p$E$$$F(B
-;;;	$B$$$^$9$,!"A`:nBN7O$O$+$J$j0c$$$^$9!#(B
+;;;	  ɥؤȸǥ screen ޥɤ˴Ť
+;;;	ޤηϤϤʤ㤤ޤ
 ;;;
-;;;$B!ZDL$J;H$$J}![(B
+;;;̤ʻȤ
 ;;;	
-;;;	windows.el 2.11 $B0J9_$G$O!"(Bframe$B$K(B
+;;;	windows.el 2.11 ʹߤǤϡframe
 ;;;
 ;;;		mule[1]:*scratch*
 ;;;	
-;;;	$B$N$h$&$J%?%$%H%k$rIU$1$^$9!#$3$l$rMxMQ$9$k$H!"%&%#%s%I%&%^%M!<%8%c(B
-;;;	$B$+$i0l7b$GL\E*$N(Bframe$B$KHt$V$3$H$,=PMh$k$h$&$K$J$j$^$9!#(Bfvwm2$B$r;H$C(B
-;;;	$B$F$$$k$H$-$O!"(B
+;;;	Τ褦ʥȥդޤѤȡɥޥ͡
+;;;	Ūframe֤Ȥ褦ˤʤޤfvwm2Ȥ
+;;;	ƤȤϡ
 ;;;	
 ;;;	AddToFunc DeiconifyFocusAndWarp "I" Iconify -1
 ;;;	+				"I" FocusAndWarp $0 $1
@@ -574,38 +582,38 @@
 ;;;	 :
 ;;;	Key 9 A C	Next [mule?9?:*] DeiconifyFocusAndWarp
 ;;;	
-;;;	$B$N$h$&$K(B ~/.fvwm2rc $B$K=q$/$3$H$G!"(BC-1 $B!A(B C-9 $B$r2!$9$3$H$GL\E*%U(B
-;;;	$B%l!<%`$KHt$V$3$H$,=PMh$k$h$&$K$J$j$^$9(B($B>\$7$/$O%&%#%s%I%&%^%M!<(B
-;;;	$B%8%c$N%^%K%e%"%k$r8+$F$/$@$5$$(B)$B!#(B
+;;;	Τ褦 ~/.fvwm2rc ˽񤯤ȤǡC-1  C-9 򲡤ȤŪ
+;;;	졼֤Ȥ褦ˤʤޤ(ܤϥɥޥ͡
+;;;	Υޥ˥奢򸫤Ƥ)
 ;;;	
-;;;$B!Z$"$H$,$-![(B
+;;;ڤȤ
 ;;;
-;;;	  $B;w$?$h$&$J$NB>$K$b$"$j$=$&!#(B $B$H$*$b$$$D$D(B fj.editor.emacs $B$KEj(B
-;;;	$B9F$7$?$H$3$m(B screens.el $B$H$$$&$^$5$K(B screen $B%3%^%s%I8_49$N$b$N$,(B
-;;;	$B$"$j$^$7$?!#(B $B$^$?(B wicos.el $B$H$$$&8e7QHG$,=P$F$$$k$h$&$G$9$,!D(B($BB?(B
-;;;	$B$/$O8l$k$^$$(B)$B!D!#(Bwindows.el $B$G$O!"(B ($BA4(B)$B%&%#%s%I%&>uBV$NJ]B8(B/$BI|85(B
-;;;	$B$,2DG=$J$N$G!"$?$@$A$KA02s$NJT=84D6-$r<h$jLa$9$3$H$,$G$-$^$9!#$=(B
-;;;	$B$l$f$(O@J8$K%$%s%W%j%a%s%H$K$HK;$7$$;~4|$K$O7g$+$;$J$$%f!<%F%#%j(B
-;;;	$B%F%#$H$J$k$G$7$g$&!#(B
+;;;	  褦ʤ¾ˤ⤢ꤽ Ȥ⤤Ĥ fj.editor.emacs 
+;;;	ƤȤ screens.el Ȥޤ screen ޥɸߴΤΤ
+;;;	ޤ ޤ wicos.el ȤǤФƤ褦Ǥ(¿
+;;;	ϸޤ)ġwindows.el Ǥϡ ()ɥ֤¸/
+;;;	ǽʤΤǡԽĶ᤹ȤǤޤ
+;;;	椨ʸ˥ץȤˤ˻ˤϷ礫ʤ桼ƥ
+;;;	ƥȤʤǤ礦
 ;;;
 ;;;
-;;;$B!Z<U<-![(B
+;;;ڼռ
 ;;;
-;;;	  $B$3$N%W%m%0%i%`$r:n$k$-$C$+$1$HE,@Z$J%3%a%s%H$r2<$5$C$?!"(BASCII-
-;;;	NET$B$N$?$j$c!<:4!9LZ$5$s!"(B Emacs-19 $B$G%_%K%P%C%U%!$rJ,N%$5$;$F$$(B
-;;;	$B$k;~$N5sF0$K4X$9$k%G%P%C%0$K6(NO2<$5$C$?(Bfujixerox.co.jp$B$NW"@%M[(B
-;;;	$B0l$5$s!"%a%K%e!<$K$h$k%&%#%s%I%&@Z$jBX$($rDs0F$7$F$/$@$5$C$?(B($B3t(B) 
-;;;	$BEl<G$N>.NSJY$5$s!"(BXEmacs$B4X78$NF0:nJs9p$J$I$rD:$$$?CfEg44IW$5$s!"(B
-;;;	$B3F%&%#%s%I%&$KL>A0$r$D$1$k5!G=$J$I$N%Q%C%A$rD:$$$?Aa0pEDBg3X$N@>(B
-;;;	$BK\$5$s$K46<UCW$7$^$9!#(B
+;;;	  Υץ뤭äŬڤʥȤ򲼤äASCII-
+;;;	NETΤ㡼ڤ Emacs-19 ǥߥ˥ХåեʬΥƤ
+;;;	εư˴ؤǥХå˶ϲäfujixerox.co.jpע
+;;;	줵󡢥˥塼ˤ륦ɥڤؤƤƤä() 
+;;;	Ǥξ٤XEmacsطưʤɤĺ紴פ
+;;;	ƥɥ̾Ĥ뵡ǽʤɤΥѥåĺؤ
+;;;	ܤ˴פޤ
 ;;;
-;;;$B!Z<h$j07$$![(B
+;;;ڼ갷
 ;;;
-;;;	  $B$3$N%W%m%0%i%`$O!"%U%j!<%=%U%H%&%'%"$H$7$FG[I[$$$?$7$^$9!#$3$N(B
-;;;	$B%W%m%0%i%`$r;HMQ$7$F@8$8$?$$$+$J$k7k2L$KBP$7$F$b:n<T$O0l@Z$N@UG$(B
-;;;	$B$rIi$o$J$$$b$N$H$$$?$7$^$9$,!"%3%a%s%H$d%P%0%l%]!<%H$OBg$$$K4?7^(B
-;;;	$B$$$?$7$^$9!#$*5$7Z$K$4O"Mm2<$5$$!#O"Mm$O0J2<$N%"%I%l%9$^$G$*4j$$(B
-;;;	$B$$$?$7$^$9(B(1999/3$B8=:_(B)$B!#(B
+;;;	  Υץϡե꡼եȥȤۤޤ
+;;;	ץѤʤ̤ФƤԤϰڤǤ
+;;;	ʤΤȤޤȤХݡȤ礤˴
+;;;	ޤڤˤϢϢϰʲΥɥ쥹ޤǤꤤ
+;;;	ޤ(2002/9)
 ;;;							yuuji@gentei.org
 
 ;;;
@@ -692,6 +700,9 @@ selected frame.")
   "*Default depth of buffer stack per window.
 If nil, do not preserve buffer-list priority")
 (defvar win:names-maxl 20 "*Title length in window list")
+(defvar win:inhibit-switch-in-minibuffer nil
+  "*Non-nil inhibits window switching in minibuffer window")
+
 
 ;;Variables for XEmacs
 (defvar win:frame-title-function
@@ -720,6 +731,38 @@ One argument of frame number should be taken.")
 
 ;; for XEmacs
 (defvar win:xemacs-p (string-match "XEmacs" emacs-version))
+(defvar win:XEmacs-remake-initial-frame win:xemacs-p
+  "*Non-nil delets initial frame and rebuild same frame with name mule[1]")
+(defun win:remake-frame ()
+  (if win:XEmacs-remake-initial-frame
+      (let ((old (selected-frame)))
+	(prog1
+	    (make-frame
+	     (cons
+	      (cons 'name "mule[1]")
+	      (mapcar '(lambda (s)
+			 (cons s (frame-property old s)))
+		      '(top left height width))))
+	  (delete-frame old)))))
+
+;; for Nemacs(Emacs-18)
+(if (fboundp 'add-hook)
+    nil
+  (defun win:add-hook (hook funcs &optional append local)
+    "Append funcs to hook's value keeping its uniquness."
+    ;;Derived from add-hook.el by Daniel LaLiberte.
+    (if (boundp hook)
+	(let ((value (symbol-value hook)))
+	  (if (and (listp value) (not (eq (car value) 'lambda)))
+	      (and (not (memq funcs value))
+		   (set hook
+			(append value (list funcs))))
+	    (and (not (eq funcs value))
+		 (set hook
+		      (list value funcs)))))
+      (set hook funcs)))
+  (fset 'add-hook 'win:add-hook))
+
 (defun win:make-frame (index &optional prop)
   "Wrapper function for make-frame;
 INDEX is a window number.  Optional second argument PROP is passed to
@@ -730,7 +773,8 @@ make-frame function."
   (if win:xemacs-p
       (make-frame (alist-to-plist prop))
     (let ((frame (make-frame prop)) (count 100))
-      (if (string-match "^20\\." emacs-version)
+      ;;(modify-frame-parameters frame prop)
+      (if (string-match "^2[01]\\." emacs-version)
 	  (progn
 	    (while (and (> count 0) (not (frame-visible-p frame)))
 	      (setq count (1- count))
@@ -766,7 +810,9 @@ make-frame function."
 	  (define-key global-map (concat prefix "=") 'win-switch-menu)
 	  (define-key global-map (concat prefix " ") 'win-toggle-window)
 	  (define-key global-map (concat prefix "!")
-	    'win-delete-current-window)))
+	    'win-delete-current-window)
+	  (define-key global-map (concat prefix "-")
+	   'win-recover-recent-winconf)))
     (setq key win:base-key)
     (while (< key max)
       (define-key win:switch-menu-map (char-to-string key)
@@ -782,6 +828,7 @@ make-frame function."
   (define-key win:switch-map "n" 'win-next-window)
   (define-key win:switch-map "\C-p" 'win-prev-window)
   (define-key win:switch-map "p" 'win-prev-window)
+  (define-key win:switch-map "-" 'win-recover-recent-winconf)
   (define-key win:switch-map "!" 'win-delete-current-window)
   ;; Key map of window selection menu.
   (define-key win:switch-menu-map "n"		'next-line)
@@ -936,22 +983,30 @@ make-frame function."
     (while (and (< d win:buffer-depth-per-win) bl)
       (or (eq (window-buffer (minibuffer-window)) (car bl))
           ;(string-match "\\*$" (buffer-name (car bl)))
-	  (progn
-	    (aset (aref win:buflists index) d (car bl)) ;buffer-list$B$N=g=xJ]B8(B
+	  (progn			;buffer-listν¸
+	    (aset (aref win:buflists index) d (buffer-name (car bl)))
 	    (setq d (1+ d))))
       (setq bl (cdr bl)))))
 
 (defun win:restore-buffer-list (index)
   "(Windows internal)Restore current window's buffer-list previously saved."
   (save-window-excursion
-    (select-window (get-largest-window))
+    (if (eq (selected-window) (minibuffer-window))
+	;;escape from minibuffer
+	(let ((wl (revive:window-list)))
+	  (while wl
+	    (select-window (car wl))
+	    (if (eq (selected-window) (minibuffer-window))
+		(setq wl (cdr wl))
+	      (setq wl nil)))))
     (let ((d win:buffer-depth-per-win) b)
+      ;(select-window (get-largest-window))
+      (delete-other-windows)
       (while (> d 0)
 	(setq d (1- d)
 	      b (aref (aref win:buflists index) d))
 	(and b
 	     (get-buffer b)
-	     (buffer-name b)
 	     (switch-to-buffer b))))))
 
 (defun win:switch-window (to &optional preserve nosetwc)
@@ -977,13 +1032,15 @@ Optional third arg NOSETWC non-nil means do not set-window-configuration TO.
       (error "Window frame [%c] does not exist." (+ win:base-key to))))
    (t
     (or preserve (win:store-config win:current-config))
-    (if win:buffer-depth-per-win (win:restore-buffer-list to))
     (or nosetwc (win:set-wc to))
+    (if win:buffer-depth-per-win
+	(save-window-excursion (win:restore-buffer-list to)))
     ))
   (win:update-mode-line to)
   (if (/= to win:current-config)
       (setq win:last-config win:current-config
 	    win:current-config to))
+  (win:memorize-current-conf-1)
   (message "Switch to window[%c]" (+ to win:base-key)))
 
 (defun win-delete-current-window (arg)
@@ -1020,6 +1077,10 @@ the window number."
                       (- last-command-char win:base-key))))
 	(wc (aref win:configs window)))
     (cond
+     ((and win:inhibit-switch-in-minibuffer
+	   (eq (minibuffer-window) (selected-window)))
+      (message "Really? Then, set win:inhibit-switch-in-minibuffer to nil!")
+      (sit-for 1))
      ;;if ARG=0, switch to recent window.
      ((= window 0) (win-recent-window))
      ;;if ARG<0, delete specified(by invoke key) window.
@@ -1047,13 +1108,13 @@ the window number."
 	      (message "Create window[%c]?(y or n):" (+ window win:base-key))
 	    (message
 	     (concat
-	      "[%c] is nil. C)reate D)uplicate "
+	      "[%c] is nil. C)reate D)up "
 	      (if win:use-frame "" "P)reserve ")
-	      "F)indfile B)uff X)M-x N)o:")
+	      "F)indfile B)uff X)M-x k)KeyFunc&exit N)o:")
 	     (+ window win:base-key)))
 	  ;;(setq ans (if (interactive-p) (read-char) ?y))
 	  (setq ans (read-char))
-	  (if (string-match (char-to-string ans) "cdpyfbx")
+	  (if (string-match (char-to-string ans) "cdpyfbxk")
 	      (let (inhibitmsg)
 		(cond
 		 ((equal ans ?f)
@@ -1077,6 +1138,24 @@ the window number."
 		    (sit-for 0)
 		    (setq inhibitmsg t)
 		    (call-interactively cmd)))
+		 ((equal ans ?k)
+		  (let ((cmd (key-binding
+			      (read-key-sequence
+			       "Keysequence function on new window(deleted in the future): "))))
+		    (win:switch-window window nil t)
+		    (delete-other-windows)
+		    (switch-to-buffer (get-buffer-create "*scratch*"))
+		    (sit-for 0)
+		    (setq inhibitmsg t)
+		    (call-interactively cmd)
+		    (make-local-variable 'kill-buffer-hook)
+		    (add-hook 'kill-buffer-hook
+			      (list 'lambda nil
+				    (list 'win:delete-window
+					  win:current-config
+					  nil t
+					  )))
+		    ))
 		 ((and (string-match (char-to-string ans) "py")
 		       (null win:use-frame))
 		  (win:switch-window window t t))
@@ -1099,12 +1178,13 @@ the window number."
   "Windows menu for operations on window configuration."
   (interactive "p")
   (message
-   "N)ext P)rev R)ecent D)elete K)ill S)ave2buf L)oad-from-buf A)saveAs sW)ap")
+   "N)ext P)rv R)ecent D)el recoV)er K)ill S)ave2buf L)oad-from-buf saveA)s sW)ap")
   (let ((c (downcase (read-char))))
     (cond
      ((= c ?n) (win-next-window arg))
      ((= c ?p) (win-prev-window arg))
      ((= c ?r) (win-recent-window))
+     ((= c ?v) (win-recover-recent-winconf arg))
      ((= c ?d) (win-delete-current-window nil))
      ((= c ?k) (win-delete-current-window t))
      ((= c ?l) (win-load-window-buffer))
@@ -1169,7 +1249,8 @@ the window number."
 (defun win:read-config-file ()
   "Read window configuration file from minibuffer."
   (let ((dir (file-name-directory win:local-config-file)))
-    (setq dir (read-file-name "Configuration file directory: " dir dir 1))
+    (setq dir (expand-file-name
+	       (read-file-name "Configuration file directory: " dir dir 1)))
     (if (not (string-match "[\\/]$" dir))
 	(setq dir (concat dir "/")))
     (if (not (file-directory-p dir)) (error "No such directory [%s]" dir))
@@ -1363,7 +1444,17 @@ Do not call this function."
 (defun win:startup-with-window ()
   "Start up Emacs with window[1] selected."
   (if (aref win:configs 1) nil
+    (and (boundp 'default-frame-plist)	;for XEmacs initial variable
+	 (listp (car default-frame-plist))
+	 (setq default-frame-plist (alist-to-plist default-frame-plist)))
     (cond
+     ((and win:xemacs-p
+	   (lax-plist-get default-frame-plist 'minibuffer))
+      (win:remake-frame)
+      (setq win:current-config 1)
+      (win:store-config 1)
+      (win:update-mode-line 1)
+      (message "Startup with window [1]"))
      ((and win:use-frame (not (interactive-p)))
       ;; When called from .emacs, since the base frame at that time
       ;; will be deleted by the function frame-notice-user-settings,
@@ -1401,6 +1492,7 @@ Do not call this function."
 				    t)
 				(not (member f (minibuffer-frame-list)))))))
 			   (visible-frame-list))))
+		     (win:remake-frame) ;to change frame title with "mule[1]"
 		     (setq win:current-config 1)
 		     (win:store-config 1)
 		     (win:update-mode-line 1)
@@ -1427,7 +1519,7 @@ Do not call this function."
 ;; Functions for resume.
 ;;;
 (defconst win:revision
-  "$Revision: 2.26 $"
+  "$Revision: 2.39 $"
   "Revision string of windows.el")
 (defvar win:revision-prefix ";win;")
 
@@ -1657,6 +1749,7 @@ Non-nil for optional argument PRESERVE keeps all current buffers."
 	    win:last-config frame)
 	(win:set-frame-configuration (car wconflist)))
       (win:store-config (car (car wconflist)))
+      (win:restore-buffer-list (car (car wconflist)))
       (setq wconflist (cdr wconflist)))
     (win:set-wc win:current-config)
     (win:update-mode-line win:current-config))
@@ -1686,10 +1779,13 @@ Non-nil for optional argument PRESERVE keeps all current buffers."
 	(select-frame goal)
 	(if (not (eq (selected-frame) goal))
 	    nil
+	  (or win:xemacs-p (unfocus-frame))
+	  ;; Emacs-21.0.9x sometimes fails to display some part of frame
+	  (if (string< "21.0.92" emacs-version)
+	      (sit-for (string-to-number "1e-5")))
 	  (apply 'set-mouse-pixel-position
 		 (if win:xemacs-p (selected-window) goal)
 		 win:mouse-position)
-	  (or win:xemacs-p (unfocus-frame))
 	  goal)))))
 
 (defun win:selected-window ()
@@ -1719,7 +1815,8 @@ window is not a member of window list."
 	    (setq win:last-config win:current-config
 		  win:current-config sw)
 	    (win:update-mode-line win:current-config))))
-      (if (and win:title-with-buffer-name (not win:xemacs-p))
+      (if (and win:title-with-buffer-name (not win:xemacs-p)
+	       win:frame-title-function)
 	  (modify-frame-parameters
 	   nil
 	   (list
@@ -1753,6 +1850,62 @@ window is not a member of window list."
       (add-hook 'pre-command-hook 'win:title-mode-line-updater)
       (add-hook 'post-command-hook 'win:title-mode-line-updater2)))
 
+(defvar win:memorized-winconf (make-vector win:max-configs nil)
+  "Vector for temporary window-configurations of each frames.")
+
+(defun win:memorize-current-conf-1 ()
+  "(windows.el internal) Memorize recent window-configuration."
+  (win:adjust-window t)
+  (aset win:memorized-winconf win:current-config (current-window-configuration)))
+
+(defun win:memorize-current-conf (&optional from to old)
+  "Memorize recent window-configuration.
+Called by after-change-functions"
+  (if (or (eq (minibuffer-window) (selected-window))
+	  (null (get-buffer-window (current-buffer)))
+	  (and (stringp (buffer-name))
+	       ;;(string-match "^[ *]" (buffer-name))
+	       ;;String-match causes error, why!!??
+	       (memq (aref (buffer-name) 0) '(?* ? ?\t))))
+      t
+    (win:memorize-current-conf-1))
+  nil)
+
+(defun win-recover-recent-winconf (arg)
+  "Recover recent window configuration
+This is useful when some elisp destroys your editing window configuration.
+With prefix ARG non-nil, restore all window configuration including
+selected window.  Without ARG, selected window and its point reserved."
+  (interactive "p")
+  (win:adjust-window)
+  (let ((memorized (aref win:memorized-winconf win:current-config))
+	(sw (selected-window))
+	(ws (window-start))
+	(p (point)))
+    (if (null memorized)
+	(message "No conf. yet.  Modify this buffer, and you get conf.")
+      (aset win:memorized-winconf win:current-config
+	    (current-window-configuration))
+      (set-window-configuration memorized)
+      (if (equal 1 arg)
+	  (progn
+	    (select-window sw)
+	    (set-window-start sw ws)
+	    (goto-char p))))))
+
+(defvar win:memorize-winconf-timing 'save
+  "*Timing of memorizing window configuration of selected frame.
+Choose one of 'save 'change.
+'save	Use write-file-hook.
+'change	Use after-change-functions.")
+
+(cond
+ ((eq win:memorize-winconf-timing 'change)
+  (add-hook 'after-change-functions 'win:memorize-current-conf nil))
+ ((eq win:memorize-winconf-timing 'save)
+  (add-hook 'write-file-hooks 'win:memorize-current-conf nil)))
+
+;(remove-hook 'after-change-functions 'win:memorize-current-conf nil)
 
 (defun win:adjust-names ()
   "Adjust window names stored in win:names (for frame environment)."
@@ -1897,7 +2050,7 @@ CONF is the window configuration at the time.")
                  (re-search-forward "(\\([A-Za-z0-9:-@]\\))" nil t)
                  (- (char-after (match-beginning 1)) win:base-key))) 
          (prefix (read-string "Window name: " (aref win:names-prefix goal))))
-    (if (> (length prefix) win:names-maxl) ;$BF|K\8lCN$i$J$$!D(B
+    (if (> (length prefix) win:names-maxl) ;ܸΤʤ
 	(setq prefix (substring prefix 0 win:names-maxl)))
     (aset win:names-prefix goal prefix)
     (win:switch-menu-prepare-menu)
@@ -2057,6 +2210,14 @@ If interactive argument KILL is non-nil, kill menu buffer and no select."
   (setq major-mode 'win:switch-menu-mode
 	mode-name "window selection"))
 
+(if (fboundp 'wrap-function-to-control-ime)
+    (progn
+      (wrap-function-to-control-ime 'win-menu t "p")
+      (wrap-function-to-control-ime 'win-switch-to-window t "p")
+      (wrap-function-to-control-ime 'win-resume-local t "P")
+      (wrap-function-to-control-ime 'win-resume-menu t "P")
+      (wrap-function-to-control-ime 'win-switch-menu t nil)))
+
 ;;;
 ;; Final setup.
 ;;;
@@ -2064,6 +2225,64 @@ If interactive argument KILL is non-nil, kill menu buffer and no select."
 (run-hooks 'win-load-hook)
 
 ;; $Log: windows.el,v $
+;; Revision 2.39  2003/03/28 11:34:41  yuuji
+;; add-hook alternative definition for Emacs-18(Nemacs)
+;;
+;; Revision 2.38  2002/09/17 15:14:13  yuuji
+;; For Meadow, wrap-function-to-control-ime against
+;; 'win-menu, 'win-switch-to-window, 'win-resume-local, 'win-resume-menu
+;; 'win-switch-menu
+;;
+;; Revision 2.37  2002/06/30 08:01:15  yuuji
+;; New variable win:inhibit-switch-in-minibuffer;
+;;  Inhibit window switching from minibuffer
+;; win:restore-buffer-list works well when called from minibuffer.
+;;
+;; Revision 2.36  2002/06/26 16:23:26  yuuji
+;; expand-file-name in win:read-config-file
+;;
+;; revision 2.35
+;; date: 2002/03/08 01:12:13;  author: yuuji;  state: Exp;  lines: +31 -14
+;; By Sean Champ <schamp@users.sourceforge.net>;
+;; win:delete-frame-with-window : added
+;; 
+;; #'win:delete-window :
+;;    if win:delete-frame-with-window is nil:
+;;          1) do not delete the frame of the window
+;;             2) do not call #'win:set-wc
+;; 
+;; these changes have been tested, and appear to work well enough.
+;; 
+;; (xemacs 21.5.4, with gtk widgets, might make some strange widgets appear
+;; in the buffer that is selected after the key-sequence C-c C-w 9 c )
+;;
+;; Revision 2.34  2002/01/29 14:09:21  yuuji
+;; Call win:restore-buffer-list in win-load-all-configurations so that
+;; buffer-list order in each window can be back at resume-windows.
+;;
+;; Revision 2.33  2001/10/28 07:57:49  yuuji
+;; Emacs21 sometimes fails to locate new frame in expected position; fixed.
+;;
+;; Revision 2.32  2001/03/07 03:44:37  yuuji
+;; Convert to EUC-JP for non-mule.
+;;
+;; Revision 2.31  2001/01/30 03:30:28  yuuji
+;; For Emacs-21.0.96 in win:switch-window;
+;; do win:restore-buffer-list after selecting target window(not frame mode)
+;;
+;; Revision 2.30  2001/01/29 09:06:10  yuuji
+;; Sit-for 1e-10 in 2.29 is too little... Change to 1e-5.
+;;
+;; Revision 2.29  2001/01/29 09:04:02  yuuji
+;; Emacs-21.0.9x sometimes fails to display some part of frame.
+;; Add sit-for to win:selected-window for workaround.
+;;
+;; Revision 2.28  2001/01/24 12:57:54  yuuji
+;; Check win:frame-title-function's void or not in win:adjust-window.
+;;
+;; Revision 2.27  2000/11/24 03:52:06  yuuji
+;; Shorten window-creation message.
+;;
 ;; Revision 2.26  1999/05/14 05:43:38  yuuji
 ;; Fix the case as below;
 ;; Start Emacs with win:startup-with-window,
